==> genometools-1.0.3.tar.gz: genometools-1.0.3/src/libgtmatch/opensfxfile.c <==
/*
  Copyright (c) 2007 Stefan Kurtz <kurtz@zbh.uni-hamburg.de>
  Copyright (c) 2007 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#include <errno.h>
#include <string.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include "libgtcore/env.h"
#include "libgtcore/str.h"

/*@null@*/ FILE *opensfxfile(const Str *indexname,
                             const char *suffix,
                             const char *mode,
                             Env *env)
{
  Str *tmpfilename;
  FILE *fp;

  env_error_check(env);
  tmpfilename = str_clone(indexname,env);
  str_append_cstr(tmpfilename,suffix,env);
  fp = env_fa_fopen(env,str_get(tmpfilename),mode);
  if (fp == NULL)
  {
    env_error_set(env,"cannot open file \"%s\": %s",str_get(tmpfilename),
                                                    strerror(errno));
  }
  str_delete(tmpfilename,env);
  return fp;
}

bool indexfilealreadyexists(const Str *indexname,const char *suffix,Env *env)
{
  struct stat statbuf;
  Str *tmpfilename;

  env_error_check(env);
  tmpfilename = str_clone(indexname,env);
  str_append_cstr(tmpfilename,suffix,env);

  if (stat(str_get(tmpfilename),&statbuf) == 0)
  {
    str_delete(tmpfilename,env);
    return true;
  }
  str_delete(tmpfilename,env);
  return false;
}

==> genometools-1.0.5.tar.gz: genometools-1.0.5/src/libgtmatch/opensfxfile.c <==
/*
  Copyright (c) 2007 Stefan Kurtz <kurtz@zbh.uni-hamburg.de>
  Copyright (c) 2007 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#include <errno.h>
#include <string.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include "libgtcore/env.h"
#include "libgtcore/str.h"

/*@null@*/ FILE *opensfxfile(const Str *indexname,
                             const char *suffix,
                             const char *mode,
                             Env *env)
{
  Str *tmpfilename;
  FILE *fp;

  env_error_check(env);
  tmpfilename = str_clone(indexname,env);
  str_append_cstr(tmpfilename,suffix,env);
  fp = env_fa_fopen(env,str_get(tmpfilename),mode);
  if (fp == NULL)
  {
    env_error_set(env,"env_fa_open: cannot open file \"%s\": %s",
                  str_get(tmpfilename),
                  strerror(errno));
  }
  str_delete(tmpfilename,env);
  return fp;
}

bool indexfilealreadyexists(const Str *indexname,const char *suffix,Env *env)
{
  struct stat statbuf;
  Str *tmpfilename;

  env_error_check(env);
  tmpfilename = str_clone(indexname,env);
  str_append_cstr(tmpfilename,suffix,env);

  if (stat(str_get(tmpfilename),&statbuf) == 0)
  {
    str_delete(tmpfilename,env);
    return true;
  }
  str_delete(tmpfilename,env);
  return false;
}
